# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmOrganization(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_control_config': 'dict[str, object]',
        'additional_seats': 'int',
        'auto_top_up_charge_amount': 'float',
        'auto_top_up_enabled': 'bool',
        'auto_top_up_trigger_amount': 'float',
        'aws_external_id': 'str',
        'billing_plan': 'str',
        'created_dt': 'datetime',
        'credit_balance': 'float',
        'description': 'str',
        'display_name': 'str',
        'edges': 'OrmOrganizationEdges',
        'id': 'int',
        'immutable_slug': 'str',
        'name': 'str',
        'on_demand_discount_rate': 'float',
        'on_premise_discount_rate': 'float',
        'organization_default_storage': 'int',
        'organization_default_volume': 'int',
        'organization_pricing_plan': 'int',
        'organization_primary_owner': 'int',
        'owner_id': 'int',
        'show_tutorial': 'bool',
        'status': 'bool',
        'stripe_customer_id': 'str',
        'stripe_subscription_id': 'str',
        'stripe_subscription_items': 'dict[str, object]',
        'updated_dt': 'datetime',
        'user_discount_rate': 'float'
    }

    attribute_map = {
        'access_control_config': 'access_control_config',
        'additional_seats': 'additional_seats',
        'auto_top_up_charge_amount': 'auto_top_up_charge_amount',
        'auto_top_up_enabled': 'auto_top_up_enabled',
        'auto_top_up_trigger_amount': 'auto_top_up_trigger_amount',
        'aws_external_id': 'aws_external_id',
        'billing_plan': 'billing_plan',
        'created_dt': 'created_dt',
        'credit_balance': 'credit_balance',
        'description': 'description',
        'display_name': 'display_name',
        'edges': 'edges',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'name': 'name',
        'on_demand_discount_rate': 'on_demand_discount_rate',
        'on_premise_discount_rate': 'on_premise_discount_rate',
        'organization_default_storage': 'organization_default_storage',
        'organization_default_volume': 'organization_default_volume',
        'organization_pricing_plan': 'organization_pricing_plan',
        'organization_primary_owner': 'organization_primary_owner',
        'owner_id': 'owner_id',
        'show_tutorial': 'show_tutorial',
        'status': 'status',
        'stripe_customer_id': 'stripe_customer_id',
        'stripe_subscription_id': 'stripe_subscription_id',
        'stripe_subscription_items': 'stripe_subscription_items',
        'updated_dt': 'updated_dt',
        'user_discount_rate': 'user_discount_rate'
    }

    def __init__(self, access_control_config=None, additional_seats=None, auto_top_up_charge_amount=None, auto_top_up_enabled=None, auto_top_up_trigger_amount=None, aws_external_id=None, billing_plan=None, created_dt=None, credit_balance=None, description=None, display_name=None, edges=None, id=None, immutable_slug=None, name=None, on_demand_discount_rate=None, on_premise_discount_rate=None, organization_default_storage=None, organization_default_volume=None, organization_pricing_plan=None, organization_primary_owner=None, owner_id=None, show_tutorial=None, status=None, stripe_customer_id=None, stripe_subscription_id=None, stripe_subscription_items=None, updated_dt=None, user_discount_rate=None, local_vars_configuration=None):  # noqa: E501
        """OrmOrganization - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._access_control_config = None
        self._additional_seats = None
        self._auto_top_up_charge_amount = None
        self._auto_top_up_enabled = None
        self._auto_top_up_trigger_amount = None
        self._aws_external_id = None
        self._billing_plan = None
        self._created_dt = None
        self._credit_balance = None
        self._description = None
        self._display_name = None
        self._edges = None
        self._id = None
        self._immutable_slug = None
        self._name = None
        self._on_demand_discount_rate = None
        self._on_premise_discount_rate = None
        self._organization_default_storage = None
        self._organization_default_volume = None
        self._organization_pricing_plan = None
        self._organization_primary_owner = None
        self._owner_id = None
        self._show_tutorial = None
        self._status = None
        self._stripe_customer_id = None
        self._stripe_subscription_id = None
        self._stripe_subscription_items = None
        self._updated_dt = None
        self._user_discount_rate = None
        self.discriminator = None

        if access_control_config is not None:
            self.access_control_config = access_control_config
        if additional_seats is not None:
            self.additional_seats = additional_seats
        if auto_top_up_charge_amount is not None:
            self.auto_top_up_charge_amount = auto_top_up_charge_amount
        if auto_top_up_enabled is not None:
            self.auto_top_up_enabled = auto_top_up_enabled
        if auto_top_up_trigger_amount is not None:
            self.auto_top_up_trigger_amount = auto_top_up_trigger_amount
        if aws_external_id is not None:
            self.aws_external_id = aws_external_id
        if billing_plan is not None:
            self.billing_plan = billing_plan
        if created_dt is not None:
            self.created_dt = created_dt
        if credit_balance is not None:
            self.credit_balance = credit_balance
        self.description = description
        if display_name is not None:
            self.display_name = display_name
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if name is not None:
            self.name = name
        if on_demand_discount_rate is not None:
            self.on_demand_discount_rate = on_demand_discount_rate
        if on_premise_discount_rate is not None:
            self.on_premise_discount_rate = on_premise_discount_rate
        self.organization_default_storage = organization_default_storage
        self.organization_default_volume = organization_default_volume
        if organization_pricing_plan is not None:
            self.organization_pricing_plan = organization_pricing_plan
        if organization_primary_owner is not None:
            self.organization_primary_owner = organization_primary_owner
        self.owner_id = owner_id
        if show_tutorial is not None:
            self.show_tutorial = show_tutorial
        if status is not None:
            self.status = status
        self.stripe_customer_id = stripe_customer_id
        self.stripe_subscription_id = stripe_subscription_id
        if stripe_subscription_items is not None:
            self.stripe_subscription_items = stripe_subscription_items
        if updated_dt is not None:
            self.updated_dt = updated_dt
        if user_discount_rate is not None:
            self.user_discount_rate = user_discount_rate

    @property
    def access_control_config(self):
        """Gets the access_control_config of this OrmOrganization.  # noqa: E501


        :return: The access_control_config of this OrmOrganization.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._access_control_config

    @access_control_config.setter
    def access_control_config(self, access_control_config):
        """Sets the access_control_config of this OrmOrganization.


        :param access_control_config: The access_control_config of this OrmOrganization.  # noqa: E501
        :type access_control_config: dict[str, object]
        """

        self._access_control_config = access_control_config

    @property
    def additional_seats(self):
        """Gets the additional_seats of this OrmOrganization.  # noqa: E501


        :return: The additional_seats of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._additional_seats

    @additional_seats.setter
    def additional_seats(self, additional_seats):
        """Sets the additional_seats of this OrmOrganization.


        :param additional_seats: The additional_seats of this OrmOrganization.  # noqa: E501
        :type additional_seats: int
        """

        self._additional_seats = additional_seats

    @property
    def auto_top_up_charge_amount(self):
        """Gets the auto_top_up_charge_amount of this OrmOrganization.  # noqa: E501


        :return: The auto_top_up_charge_amount of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._auto_top_up_charge_amount

    @auto_top_up_charge_amount.setter
    def auto_top_up_charge_amount(self, auto_top_up_charge_amount):
        """Sets the auto_top_up_charge_amount of this OrmOrganization.


        :param auto_top_up_charge_amount: The auto_top_up_charge_amount of this OrmOrganization.  # noqa: E501
        :type auto_top_up_charge_amount: float
        """

        self._auto_top_up_charge_amount = auto_top_up_charge_amount

    @property
    def auto_top_up_enabled(self):
        """Gets the auto_top_up_enabled of this OrmOrganization.  # noqa: E501


        :return: The auto_top_up_enabled of this OrmOrganization.  # noqa: E501
        :rtype: bool
        """
        return self._auto_top_up_enabled

    @auto_top_up_enabled.setter
    def auto_top_up_enabled(self, auto_top_up_enabled):
        """Sets the auto_top_up_enabled of this OrmOrganization.


        :param auto_top_up_enabled: The auto_top_up_enabled of this OrmOrganization.  # noqa: E501
        :type auto_top_up_enabled: bool
        """

        self._auto_top_up_enabled = auto_top_up_enabled

    @property
    def auto_top_up_trigger_amount(self):
        """Gets the auto_top_up_trigger_amount of this OrmOrganization.  # noqa: E501


        :return: The auto_top_up_trigger_amount of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._auto_top_up_trigger_amount

    @auto_top_up_trigger_amount.setter
    def auto_top_up_trigger_amount(self, auto_top_up_trigger_amount):
        """Sets the auto_top_up_trigger_amount of this OrmOrganization.


        :param auto_top_up_trigger_amount: The auto_top_up_trigger_amount of this OrmOrganization.  # noqa: E501
        :type auto_top_up_trigger_amount: float
        """

        self._auto_top_up_trigger_amount = auto_top_up_trigger_amount

    @property
    def aws_external_id(self):
        """Gets the aws_external_id of this OrmOrganization.  # noqa: E501


        :return: The aws_external_id of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._aws_external_id

    @aws_external_id.setter
    def aws_external_id(self, aws_external_id):
        """Sets the aws_external_id of this OrmOrganization.


        :param aws_external_id: The aws_external_id of this OrmOrganization.  # noqa: E501
        :type aws_external_id: str
        """

        self._aws_external_id = aws_external_id

    @property
    def billing_plan(self):
        """Gets the billing_plan of this OrmOrganization.  # noqa: E501


        :return: The billing_plan of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._billing_plan

    @billing_plan.setter
    def billing_plan(self, billing_plan):
        """Sets the billing_plan of this OrmOrganization.


        :param billing_plan: The billing_plan of this OrmOrganization.  # noqa: E501
        :type billing_plan: str
        """

        self._billing_plan = billing_plan

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmOrganization.  # noqa: E501


        :return: The created_dt of this OrmOrganization.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmOrganization.


        :param created_dt: The created_dt of this OrmOrganization.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def credit_balance(self):
        """Gets the credit_balance of this OrmOrganization.  # noqa: E501


        :return: The credit_balance of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._credit_balance

    @credit_balance.setter
    def credit_balance(self, credit_balance):
        """Sets the credit_balance of this OrmOrganization.


        :param credit_balance: The credit_balance of this OrmOrganization.  # noqa: E501
        :type credit_balance: float
        """

        self._credit_balance = credit_balance

    @property
    def description(self):
        """Gets the description of this OrmOrganization.  # noqa: E501


        :return: The description of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this OrmOrganization.


        :param description: The description of this OrmOrganization.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def display_name(self):
        """Gets the display_name of this OrmOrganization.  # noqa: E501


        :return: The display_name of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this OrmOrganization.


        :param display_name: The display_name of this OrmOrganization.  # noqa: E501
        :type display_name: str
        """

        self._display_name = display_name

    @property
    def edges(self):
        """Gets the edges of this OrmOrganization.  # noqa: E501


        :return: The edges of this OrmOrganization.  # noqa: E501
        :rtype: OrmOrganizationEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmOrganization.


        :param edges: The edges of this OrmOrganization.  # noqa: E501
        :type edges: OrmOrganizationEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmOrganization.  # noqa: E501


        :return: The id of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmOrganization.


        :param id: The id of this OrmOrganization.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmOrganization.  # noqa: E501


        :return: The immutable_slug of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmOrganization.


        :param immutable_slug: The immutable_slug of this OrmOrganization.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def name(self):
        """Gets the name of this OrmOrganization.  # noqa: E501


        :return: The name of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmOrganization.


        :param name: The name of this OrmOrganization.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def on_demand_discount_rate(self):
        """Gets the on_demand_discount_rate of this OrmOrganization.  # noqa: E501


        :return: The on_demand_discount_rate of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._on_demand_discount_rate

    @on_demand_discount_rate.setter
    def on_demand_discount_rate(self, on_demand_discount_rate):
        """Sets the on_demand_discount_rate of this OrmOrganization.


        :param on_demand_discount_rate: The on_demand_discount_rate of this OrmOrganization.  # noqa: E501
        :type on_demand_discount_rate: float
        """

        self._on_demand_discount_rate = on_demand_discount_rate

    @property
    def on_premise_discount_rate(self):
        """Gets the on_premise_discount_rate of this OrmOrganization.  # noqa: E501


        :return: The on_premise_discount_rate of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._on_premise_discount_rate

    @on_premise_discount_rate.setter
    def on_premise_discount_rate(self, on_premise_discount_rate):
        """Sets the on_premise_discount_rate of this OrmOrganization.


        :param on_premise_discount_rate: The on_premise_discount_rate of this OrmOrganization.  # noqa: E501
        :type on_premise_discount_rate: float
        """

        self._on_premise_discount_rate = on_premise_discount_rate

    @property
    def organization_default_storage(self):
        """Gets the organization_default_storage of this OrmOrganization.  # noqa: E501


        :return: The organization_default_storage of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._organization_default_storage

    @organization_default_storage.setter
    def organization_default_storage(self, organization_default_storage):
        """Sets the organization_default_storage of this OrmOrganization.


        :param organization_default_storage: The organization_default_storage of this OrmOrganization.  # noqa: E501
        :type organization_default_storage: int
        """

        self._organization_default_storage = organization_default_storage

    @property
    def organization_default_volume(self):
        """Gets the organization_default_volume of this OrmOrganization.  # noqa: E501


        :return: The organization_default_volume of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._organization_default_volume

    @organization_default_volume.setter
    def organization_default_volume(self, organization_default_volume):
        """Sets the organization_default_volume of this OrmOrganization.


        :param organization_default_volume: The organization_default_volume of this OrmOrganization.  # noqa: E501
        :type organization_default_volume: int
        """

        self._organization_default_volume = organization_default_volume

    @property
    def organization_pricing_plan(self):
        """Gets the organization_pricing_plan of this OrmOrganization.  # noqa: E501


        :return: The organization_pricing_plan of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._organization_pricing_plan

    @organization_pricing_plan.setter
    def organization_pricing_plan(self, organization_pricing_plan):
        """Sets the organization_pricing_plan of this OrmOrganization.


        :param organization_pricing_plan: The organization_pricing_plan of this OrmOrganization.  # noqa: E501
        :type organization_pricing_plan: int
        """

        self._organization_pricing_plan = organization_pricing_plan

    @property
    def organization_primary_owner(self):
        """Gets the organization_primary_owner of this OrmOrganization.  # noqa: E501


        :return: The organization_primary_owner of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._organization_primary_owner

    @organization_primary_owner.setter
    def organization_primary_owner(self, organization_primary_owner):
        """Sets the organization_primary_owner of this OrmOrganization.


        :param organization_primary_owner: The organization_primary_owner of this OrmOrganization.  # noqa: E501
        :type organization_primary_owner: int
        """

        self._organization_primary_owner = organization_primary_owner

    @property
    def owner_id(self):
        """Gets the owner_id of this OrmOrganization.  # noqa: E501


        :return: The owner_id of this OrmOrganization.  # noqa: E501
        :rtype: int
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this OrmOrganization.


        :param owner_id: The owner_id of this OrmOrganization.  # noqa: E501
        :type owner_id: int
        """

        self._owner_id = owner_id

    @property
    def show_tutorial(self):
        """Gets the show_tutorial of this OrmOrganization.  # noqa: E501


        :return: The show_tutorial of this OrmOrganization.  # noqa: E501
        :rtype: bool
        """
        return self._show_tutorial

    @show_tutorial.setter
    def show_tutorial(self, show_tutorial):
        """Sets the show_tutorial of this OrmOrganization.


        :param show_tutorial: The show_tutorial of this OrmOrganization.  # noqa: E501
        :type show_tutorial: bool
        """

        self._show_tutorial = show_tutorial

    @property
    def status(self):
        """Gets the status of this OrmOrganization.  # noqa: E501


        :return: The status of this OrmOrganization.  # noqa: E501
        :rtype: bool
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this OrmOrganization.


        :param status: The status of this OrmOrganization.  # noqa: E501
        :type status: bool
        """

        self._status = status

    @property
    def stripe_customer_id(self):
        """Gets the stripe_customer_id of this OrmOrganization.  # noqa: E501


        :return: The stripe_customer_id of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._stripe_customer_id

    @stripe_customer_id.setter
    def stripe_customer_id(self, stripe_customer_id):
        """Sets the stripe_customer_id of this OrmOrganization.


        :param stripe_customer_id: The stripe_customer_id of this OrmOrganization.  # noqa: E501
        :type stripe_customer_id: str
        """

        self._stripe_customer_id = stripe_customer_id

    @property
    def stripe_subscription_id(self):
        """Gets the stripe_subscription_id of this OrmOrganization.  # noqa: E501


        :return: The stripe_subscription_id of this OrmOrganization.  # noqa: E501
        :rtype: str
        """
        return self._stripe_subscription_id

    @stripe_subscription_id.setter
    def stripe_subscription_id(self, stripe_subscription_id):
        """Sets the stripe_subscription_id of this OrmOrganization.


        :param stripe_subscription_id: The stripe_subscription_id of this OrmOrganization.  # noqa: E501
        :type stripe_subscription_id: str
        """

        self._stripe_subscription_id = stripe_subscription_id

    @property
    def stripe_subscription_items(self):
        """Gets the stripe_subscription_items of this OrmOrganization.  # noqa: E501


        :return: The stripe_subscription_items of this OrmOrganization.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._stripe_subscription_items

    @stripe_subscription_items.setter
    def stripe_subscription_items(self, stripe_subscription_items):
        """Sets the stripe_subscription_items of this OrmOrganization.


        :param stripe_subscription_items: The stripe_subscription_items of this OrmOrganization.  # noqa: E501
        :type stripe_subscription_items: dict[str, object]
        """

        self._stripe_subscription_items = stripe_subscription_items

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmOrganization.  # noqa: E501


        :return: The updated_dt of this OrmOrganization.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmOrganization.


        :param updated_dt: The updated_dt of this OrmOrganization.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    @property
    def user_discount_rate(self):
        """Gets the user_discount_rate of this OrmOrganization.  # noqa: E501


        :return: The user_discount_rate of this OrmOrganization.  # noqa: E501
        :rtype: float
        """
        return self._user_discount_rate

    @user_discount_rate.setter
    def user_discount_rate(self, user_discount_rate):
        """Sets the user_discount_rate of this OrmOrganization.


        :param user_discount_rate: The user_discount_rate of this OrmOrganization.  # noqa: E501
        :type user_discount_rate: float
        """

        self._user_discount_rate = user_discount_rate

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmOrganization):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmOrganization):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseVolumeMountInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'archive_file': 'OrmVolumeSourceArchiveFile',
        'code': 'OrmVolumeSourceCode',
        'dataset': 'ResponseVolumeSourceDataset',
        'dataset_version': 'ResponseVolumeSourceDatasetVersion',
        'is_dir': 'bool',
        'model_volume': 'OrmVolumeSourceModelVolume',
        'mount_type': 'str',
        'path': 'str',
        'read_only': 'bool',
        'size': 'int',
        'source_type': 'str',
        'volume': 'ResponseVolumeSourceVolume'
    }

    attribute_map = {
        'archive_file': 'archive_file',
        'code': 'code',
        'dataset': 'dataset',
        'dataset_version': 'dataset_version',
        'is_dir': 'is_dir',
        'model_volume': 'model_volume',
        'mount_type': 'mount_type',
        'path': 'path',
        'read_only': 'read_only',
        'size': 'size',
        'source_type': 'source_type',
        'volume': 'volume'
    }

    def __init__(self, archive_file=None, code=None, dataset=None, dataset_version=None, is_dir=None, model_volume=None, mount_type=None, path=None, read_only=None, size=None, source_type=None, volume=None, local_vars_configuration=None):  # noqa: E501
        """ResponseVolumeMountInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._archive_file = None
        self._code = None
        self._dataset = None
        self._dataset_version = None
        self._is_dir = None
        self._model_volume = None
        self._mount_type = None
        self._path = None
        self._read_only = None
        self._size = None
        self._source_type = None
        self._volume = None
        self.discriminator = None

        if archive_file is not None:
            self.archive_file = archive_file
        if code is not None:
            self.code = code
        if dataset is not None:
            self.dataset = dataset
        if dataset_version is not None:
            self.dataset_version = dataset_version
        self.is_dir = is_dir
        if model_volume is not None:
            self.model_volume = model_volume
        self.mount_type = mount_type
        self.path = path
        self.read_only = read_only
        self.size = size
        self.source_type = source_type
        if volume is not None:
            self.volume = volume

    @property
    def archive_file(self):
        """Gets the archive_file of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The archive_file of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: OrmVolumeSourceArchiveFile
        """
        return self._archive_file

    @archive_file.setter
    def archive_file(self, archive_file):
        """Sets the archive_file of this ResponseVolumeMountInfo.


        :param archive_file: The archive_file of this ResponseVolumeMountInfo.  # noqa: E501
        :type archive_file: OrmVolumeSourceArchiveFile
        """

        self._archive_file = archive_file

    @property
    def code(self):
        """Gets the code of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The code of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: OrmVolumeSourceCode
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this ResponseVolumeMountInfo.


        :param code: The code of this ResponseVolumeMountInfo.  # noqa: E501
        :type code: OrmVolumeSourceCode
        """

        self._code = code

    @property
    def dataset(self):
        """Gets the dataset of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The dataset of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: ResponseVolumeSourceDataset
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this ResponseVolumeMountInfo.


        :param dataset: The dataset of this ResponseVolumeMountInfo.  # noqa: E501
        :type dataset: ResponseVolumeSourceDataset
        """

        self._dataset = dataset

    @property
    def dataset_version(self):
        """Gets the dataset_version of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The dataset_version of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: ResponseVolumeSourceDatasetVersion
        """
        return self._dataset_version

    @dataset_version.setter
    def dataset_version(self, dataset_version):
        """Sets the dataset_version of this ResponseVolumeMountInfo.


        :param dataset_version: The dataset_version of this ResponseVolumeMountInfo.  # noqa: E501
        :type dataset_version: ResponseVolumeSourceDatasetVersion
        """

        self._dataset_version = dataset_version

    @property
    def is_dir(self):
        """Gets the is_dir of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The is_dir of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_dir

    @is_dir.setter
    def is_dir(self, is_dir):
        """Sets the is_dir of this ResponseVolumeMountInfo.


        :param is_dir: The is_dir of this ResponseVolumeMountInfo.  # noqa: E501
        :type is_dir: bool
        """
        if self.local_vars_configuration.client_side_validation and is_dir is None:  # noqa: E501
            raise ValueError("Invalid value for `is_dir`, must not be `None`")  # noqa: E501

        self._is_dir = is_dir

    @property
    def model_volume(self):
        """Gets the model_volume of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The model_volume of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: OrmVolumeSourceModelVolume
        """
        return self._model_volume

    @model_volume.setter
    def model_volume(self, model_volume):
        """Sets the model_volume of this ResponseVolumeMountInfo.


        :param model_volume: The model_volume of this ResponseVolumeMountInfo.  # noqa: E501
        :type model_volume: OrmVolumeSourceModelVolume
        """

        self._model_volume = model_volume

    @property
    def mount_type(self):
        """Gets the mount_type of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The mount_type of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: str
        """
        return self._mount_type

    @mount_type.setter
    def mount_type(self, mount_type):
        """Sets the mount_type of this ResponseVolumeMountInfo.


        :param mount_type: The mount_type of this ResponseVolumeMountInfo.  # noqa: E501
        :type mount_type: str
        """
        if self.local_vars_configuration.client_side_validation and mount_type is None:  # noqa: E501
            raise ValueError("Invalid value for `mount_type`, must not be `None`")  # noqa: E501

        self._mount_type = mount_type

    @property
    def path(self):
        """Gets the path of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The path of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ResponseVolumeMountInfo.


        :param path: The path of this ResponseVolumeMountInfo.  # noqa: E501
        :type path: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def read_only(self):
        """Gets the read_only of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The read_only of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this ResponseVolumeMountInfo.


        :param read_only: The read_only of this ResponseVolumeMountInfo.  # noqa: E501
        :type read_only: bool
        """
        if self.local_vars_configuration.client_side_validation and read_only is None:  # noqa: E501
            raise ValueError("Invalid value for `read_only`, must not be `None`")  # noqa: E501

        self._read_only = read_only

    @property
    def size(self):
        """Gets the size of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The size of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ResponseVolumeMountInfo.


        :param size: The size of this ResponseVolumeMountInfo.  # noqa: E501
        :type size: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def source_type(self):
        """Gets the source_type of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The source_type of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this ResponseVolumeMountInfo.


        :param source_type: The source_type of this ResponseVolumeMountInfo.  # noqa: E501
        :type source_type: str
        """
        if self.local_vars_configuration.client_side_validation and source_type is None:  # noqa: E501
            raise ValueError("Invalid value for `source_type`, must not be `None`")  # noqa: E501

        self._source_type = source_type

    @property
    def volume(self):
        """Gets the volume of this ResponseVolumeMountInfo.  # noqa: E501


        :return: The volume of this ResponseVolumeMountInfo.  # noqa: E501
        :rtype: ResponseVolumeSourceVolume
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this ResponseVolumeMountInfo.


        :param volume: The volume of this ResponseVolumeMountInfo.  # noqa: E501
        :type volume: ResponseVolumeSourceVolume
        """

        self._volume = volume

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseVolumeMountInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseVolumeMountInfo):
            return True

        return self.to_dict() != other.to_dict()



import os
import tempfile
from pathlib import Path

import humanfriendly

VESSL_LOG_LEVEL_DEBUG = "DEBUG"
VESSL_LOG_LEVEL_INFO = "INFO"
VESSL_LOG_LEVEL_WARNING = "WARNING"
VESSL_LOG_LEVEL_ERROR = "ERROR"
VESSL_LOG_LEVEL_LEVELS = [
    VESSL_LOG_LEVEL_DEBUG,
    VESSL_LOG_LEVEL_INFO,
    VESSL_LOG_LEVEL_WARNING,
    VESSL_LOG_LEVEL_ERROR,
]

VESSL_LOG_LEVEL = (
    os.environ.get("VESSL_LOG")
    if os.environ.get("VESSL_LOG") in VESSL_LOG_LEVEL_LEVELS
    else VESSL_LOG_LEVEL_WARNING
)
WEB_HOST = os.environ.get("VESSL_WEB_HOST", "https://vessl.ai")
API_HOST = os.environ.get("VESSL_API_HOST", "https://api.vessl.ai")

DEFAULT_VESSL_SIDECAR_HOST = os.environ.get("VESSL_SIDECAR_HOST", "http://localhost:3000")
UPDATE_CONTEXT_VARIABLE_URL = f"{DEFAULT_VESSL_SIDECAR_HOST}/store"
GET_ARGUMENT_VALUE_URL = f"{DEFAULT_VESSL_SIDECAR_HOST}/argument"
GET_CONTEXT_VARIABLE_URL = f"{DEFAULT_VESSL_SIDECAR_HOST}/context"

LOGIN_TIMEOUT_SECONDS = 160
ACCESS_TOKEN_ENV_VAR = "VESSL_ACCESS_TOKEN"
DEFAULT_ORGANIZATION_ENV_VAR = "VESSL_DEFAULT_ORGANIZATION"
DEFAULT_PROJECT_ENV_VAR = "VESSL_DEFAULT_PROJECT"
CREDENTIALS_FILE_ENV_VAR = "VESSL_CREDENTIALS_FILE"

CLUSTER_KUBECONFIG_ENV_VAR = "VESSL_CLUSTER_KUBECONFIG"
CLUSTER_MODE_SINGLE = "single"
CLUSTER_MODE_MULTI_NODE = "multi"

PROJECT_TYPE_VERSION_CONTROL = "version-control"
PROJECT_TYPES = [PROJECT_TYPE_VERSION_CONTROL]

DATASET_PATH_SCHEME_S3 = "s3://"
DATASET_PATH_SCHEME_GS = "gs://"

DATASET_VERSION_HASH_LATEST = "latest"

PROCESSOR_TYPE_CPU = "CPU"
PROCESSOR_TYPE_GPU = "GPU"
PROCESSOR_TYPES = [PROCESSOR_TYPE_CPU, PROCESSOR_TYPE_GPU]

SWEEP_OBJECTIVE_TYPE_MAXIMIZE = "maximize"
SWEEP_OBJECTIVE_TYPE_MINIMIZE = "minimize"
SWEEP_OBJECTIVE_TYPES = [SWEEP_OBJECTIVE_TYPE_MAXIMIZE, SWEEP_OBJECTIVE_TYPE_MINIMIZE]

SWEEP_ALGORITHM_TYPE_GRID = "grid"
SWEEP_ALGORITHM_TYPE_RANDOM = "random"
SWEEP_ALGORITHM_TYPE_BAYESIAN = "bayesian"
SWEEP_ALGORITHM_TYPES = [
    SWEEP_ALGORITHM_TYPE_GRID,
    SWEEP_ALGORITHM_TYPE_RANDOM,
    SWEEP_ALGORITHM_TYPE_BAYESIAN,
]

SWEEP_PARAMETER_TYPE_CATEGORICAL = "categorical"
SWEEP_PARAMETER_TYPE_INT = "int"
SWEEP_PARAMETER_TYPE_DOUBLE = "double"
SWEEP_PARAMETER_TYPES = [
    SWEEP_PARAMETER_TYPE_CATEGORICAL,
    SWEEP_PARAMETER_TYPE_INT,
    SWEEP_PARAMETER_TYPE_DOUBLE,
]

SWEEP_PARAMETER_RANGE_TYPE_SPACE = "space"
SWEEP_PARAMETER_RANGE_TYPE_LIST = "list"
SWEEP_PARAMETER_RANGE_TYPES = [
    SWEEP_PARAMETER_RANGE_TYPE_SPACE,
    SWEEP_PARAMETER_RANGE_TYPE_LIST,
]

MODEL_SOURCE_EXPERIMENT = "experiment"
MODEL_SOURCE_LOCAL = "local"

SOURCE_TYPE_CODE = "code"
SOURCE_TYPE_ARCHIVE_FILE = "archive-file"
SOURCE_TYPE_DATASET = "dataset"
SOURCE_TYPE_DATASET_VERSION = "dataset-version"
SOURCE_TYPE_MODEL_VOLUME = "model-volume"
SOURCE_TYPE_EMPTY_DIR = "empty-dir"
SOURCE_TYPE_OUTPUT = "output"
SOURCE_TYPE_PROJECT = "project"

MOUNT_PATH_EMPTY_DIR = "/root/"
MOUNT_PATH_OUTPUT = "/output/"
MOUNT_PATH_PROJECT = "/root/{}"

EXPERIMENT_WORKING_DIR = "/root/"

FRAMEWORK_TYPE_PYTORCH = "pytorch"
FRAMEWORK_TYPE_TENSORFLOW = "tensorflow"
FRAMEWORK_TYPES = (FRAMEWORK_TYPE_PYTORCH, FRAMEWORK_TYPE_TENSORFLOW)

PARALLEL_WORKERS = os.environ.get("VESSL_PARALLEL_WORKERS", 20)

VESSL_MEDIA_PATH = "vessl-media"
VESSL_IMAGE_PATH = "images"
VESSL_AUDIO_PATH = "audio"
VESSL_PLOTS_FILETYPE_IMAGE = "image"
VESSL_PLOTS_FILETYPE_IMAGES = "images"
VESSL_PLOTS_FILETYPE_AUDIO = "audio"

WORKSPACE_BACKUP_MAX_SIZE = 15 * 1024 * 1024 * 1024
WORKSPACE_BACKUP_MAX_SIZE_FORMATTED = humanfriendly.format_size(
    WORKSPACE_BACKUP_MAX_SIZE, binary=True
)

TEMP_DIR = tempfile.gettempdir()

SSH_CONFIG_PATH = os.path.join(Path.home(), ".ssh", "config")
SSH_CONFIG_FORMAT = """Host {host}
    User root
    Hostname {hostname}
    Port {port}
    StrictHostKeyChecking accept-new
    CheckHostIP no
"""
SSH_PUBLIC_KEY_PATH = os.path.join(Path.home(), ".ssh", "id_ed25519.pub")
SSH_PRIVATE_KEY_PATH = os.path.join(Path.home(), ".ssh", "id_ed25519")



import logging
import sys
import time
from typing import Optional

from vessl.util.constant import VESSL_LOG_LEVEL

LEVEL_MAP = {
    logging.FATAL: "F",  # FATAL is alias of CRITICAL
    logging.ERROR: "E",
    logging.WARN: "W",
    logging.INFO: "I",
    logging.DEBUG: "D",
}


class Formatter(logging.Formatter):
    def format(self, record: logging.LogRecord):
        level = LEVEL_MAP.get(record.levelno, "?")

        try:
            formatted_msg = "%s" % (record.msg % record.args)
        except TypeError:
            formatted_msg = record.msg

        record_time = time.localtime(record.created)
        record_message = [
            (
                "%c%02d%02d %02d:%02d:%02d.%06d %s %s:%d] %s"
                % (
                    level,
                    record_time.tm_mon,
                    record_time.tm_mday,
                    record_time.tm_hour,
                    record_time.tm_min,
                    record_time.tm_sec,
                    (record.created - int(record.created)) * 1e6,
                    record.process if record.process is not None else "?????",
                    record.filename,
                    record.lineno,
                    line,
                )
            )
            for line in formatted_msg.split("\n")
        ]
        record_message = "\n".join(record_message)
        record.getMessage = lambda: record_message
        return super().format(record)


class VesslLogger(object):
    def __init__(self):
        self._logger = logging.getLogger(__name__)
        self._handler: Optional[logging.Handler] = None

        self.set_level(VESSL_LOG_LEVEL)  # TODO: autodiscover from config
        self.set_io(sys.stderr)

    def set_io(self, io):
        if self._handler:
            self._logger.removeHandler(self._handler)

        self._handler = logging.StreamHandler(stream=io)
        self._handler.setFormatter(Formatter())
        self._logger.addHandler(self._handler)

    def set_level(self, level):
        self._logger.setLevel(level)


_vessl_logger = VesslLogger()

logger = _vessl_logger._logger
set_log_io = _vessl_logger.set_io
set_log_level = _vessl_logger.set_level



import click

from openapi_client import ResponseKernelResourceSpec
from vessl.cli._base import VesslGroup, vessl_argument, vessl_option
from vessl.cli._util import format_bool, print_data, print_table, prompt_choices
from vessl.cli.kernel_cluster import cluster_id_prompter
from vessl.cli.organization import organization_name_option
from vessl.kernel_resource_spec import (
    list_kernel_resource_specs,
    read_kernel_resource_spec,
)


def resource_name_prompter(ctx: click.Context, param: click.Parameter, value: str) -> str:
    cluster = ctx.obj.get("cluster")
    if cluster is None:
        raise click.BadOptionUsage(
            option_name="--cluster",
            message="Cluster (`--cluster`) must be specified before resource (`--resource`).",
        )

    if ctx.params.get("processor_type") is None:
        resources = list_kernel_resource_specs(cluster_id=cluster.id)
        options = [(x.name, x) for x in resources]
        if cluster.provider != "VESSL":
            options.append(
                ("Custom", ResponseKernelResourceSpec(name="")),
            )

        resource = prompt_choices("Resource", options)
        if resource.processor_type is not None:
            ctx.obj["processor_type"] = resource.processor_type

        return resource.name


def resource_name_callback(ctx: click.Context, param: click.Parameter, value: str) -> str:
    if "cluster" not in ctx.obj:
        raise click.BadOptionUsage(
            option_name="--cluster",
            message="Cluster (`--cluster`) must be specified before resource (`--resource`).",
        )

    cluster = ctx.obj.get("cluster")
    if value and "resource" not in ctx.obj:
        ctx.obj["resource"] = read_kernel_resource_spec(cluster.id, value)

    return value


@click.command(name="resource", cls=VesslGroup)
def cli():
    pass


@cli.vessl_command()
@vessl_argument(
    "cluster",
    type=click.INT,
    required=True,
    prompter=cluster_id_prompter,
)
@vessl_argument("name", type=click.STRING, required=True, prompter=resource_name_prompter)
@organization_name_option
def read(cluster: int, name: str):
    resource = read_kernel_resource_spec(cluster_id=cluster, kernel_resource_spec_name=name)
    print_data(
        {
            "ID": resource.id,
            "Name": resource.name,
            "Description": resource.description,
            "CPU Type": resource.cpu_type,
            "CPU Limit": resource.cpu_limit,
            "GPU Type": resource.gpu_type,
            "GPU Limit": resource.gpu_limit,
            "Memory Limit": resource.memory_limit,
            "Spot": format_bool(resource.spot),
        }
    )


@cli.vessl_command()
@vessl_argument(
    "cluster",
    type=click.INT,
    required=True,
    prompter=cluster_id_prompter,
)
@organization_name_option
def list(cluster: int):
    resources = list_kernel_resource_specs(cluster_id=cluster)
    print_table(
        resources,
        [
            "ID",
            "Name",
            "CPU Type",
            "CPU Limit",
            "GPU Type",
            "GPU Limit",
            "Memory Limit",
            "Spot",
        ],
        lambda x: [
            x.id,
            x.name,
            x.cpu_type,
            x.cpu_limit,
            x.gpu_type,
            x.gpu_limit,
            x.memory_limit,
            x.spot,
        ],
    )


resource_option = vessl_option(
    "-r",
    "--resource",
    type=click.STRING,
    prompter=resource_name_prompter,
    callback=resource_name_callback,
    help="Resource type to run experiment.",
)



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmStorage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'base_path': 'str',
        'bucket_name': 'str',
        'created_dt': 'datetime',
        'edges': 'OrmStorageEdges',
        'id': 'int',
        'immutable_slug': 'str',
        'is_public_bucket': 'bool',
        'is_vessl_managed': 'bool',
        'organization_credentials_id': 'int',
        'provider': 'str',
        'region_id': 'int',
        'storage_organization': 'int',
        'updated_dt': 'datetime'
    }

    attribute_map = {
        'base_path': 'base_path',
        'bucket_name': 'bucket_name',
        'created_dt': 'created_dt',
        'edges': 'edges',
        'id': 'id',
        'immutable_slug': 'immutable_slug',
        'is_public_bucket': 'is_public_bucket',
        'is_vessl_managed': 'is_vessl_managed',
        'organization_credentials_id': 'organization_credentials_id',
        'provider': 'provider',
        'region_id': 'region_id',
        'storage_organization': 'storage_organization',
        'updated_dt': 'updated_dt'
    }

    def __init__(self, base_path=None, bucket_name=None, created_dt=None, edges=None, id=None, immutable_slug=None, is_public_bucket=None, is_vessl_managed=None, organization_credentials_id=None, provider=None, region_id=None, storage_organization=None, updated_dt=None, local_vars_configuration=None):  # noqa: E501
        """OrmStorage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._base_path = None
        self._bucket_name = None
        self._created_dt = None
        self._edges = None
        self._id = None
        self._immutable_slug = None
        self._is_public_bucket = None
        self._is_vessl_managed = None
        self._organization_credentials_id = None
        self._provider = None
        self._region_id = None
        self._storage_organization = None
        self._updated_dt = None
        self.discriminator = None

        self.base_path = base_path
        if bucket_name is not None:
            self.bucket_name = bucket_name
        if created_dt is not None:
            self.created_dt = created_dt
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if immutable_slug is not None:
            self.immutable_slug = immutable_slug
        if is_public_bucket is not None:
            self.is_public_bucket = is_public_bucket
        if is_vessl_managed is not None:
            self.is_vessl_managed = is_vessl_managed
        self.organization_credentials_id = organization_credentials_id
        if provider is not None:
            self.provider = provider
        self.region_id = region_id
        self.storage_organization = storage_organization
        if updated_dt is not None:
            self.updated_dt = updated_dt

    @property
    def base_path(self):
        """Gets the base_path of this OrmStorage.  # noqa: E501


        :return: The base_path of this OrmStorage.  # noqa: E501
        :rtype: str
        """
        return self._base_path

    @base_path.setter
    def base_path(self, base_path):
        """Sets the base_path of this OrmStorage.


        :param base_path: The base_path of this OrmStorage.  # noqa: E501
        :type base_path: str
        """

        self._base_path = base_path

    @property
    def bucket_name(self):
        """Gets the bucket_name of this OrmStorage.  # noqa: E501


        :return: The bucket_name of this OrmStorage.  # noqa: E501
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """Sets the bucket_name of this OrmStorage.


        :param bucket_name: The bucket_name of this OrmStorage.  # noqa: E501
        :type bucket_name: str
        """

        self._bucket_name = bucket_name

    @property
    def created_dt(self):
        """Gets the created_dt of this OrmStorage.  # noqa: E501


        :return: The created_dt of this OrmStorage.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this OrmStorage.


        :param created_dt: The created_dt of this OrmStorage.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def edges(self):
        """Gets the edges of this OrmStorage.  # noqa: E501


        :return: The edges of this OrmStorage.  # noqa: E501
        :rtype: OrmStorageEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmStorage.


        :param edges: The edges of this OrmStorage.  # noqa: E501
        :type edges: OrmStorageEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmStorage.  # noqa: E501


        :return: The id of this OrmStorage.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmStorage.


        :param id: The id of this OrmStorage.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def immutable_slug(self):
        """Gets the immutable_slug of this OrmStorage.  # noqa: E501


        :return: The immutable_slug of this OrmStorage.  # noqa: E501
        :rtype: str
        """
        return self._immutable_slug

    @immutable_slug.setter
    def immutable_slug(self, immutable_slug):
        """Sets the immutable_slug of this OrmStorage.


        :param immutable_slug: The immutable_slug of this OrmStorage.  # noqa: E501
        :type immutable_slug: str
        """

        self._immutable_slug = immutable_slug

    @property
    def is_public_bucket(self):
        """Gets the is_public_bucket of this OrmStorage.  # noqa: E501


        :return: The is_public_bucket of this OrmStorage.  # noqa: E501
        :rtype: bool
        """
        return self._is_public_bucket

    @is_public_bucket.setter
    def is_public_bucket(self, is_public_bucket):
        """Sets the is_public_bucket of this OrmStorage.


        :param is_public_bucket: The is_public_bucket of this OrmStorage.  # noqa: E501
        :type is_public_bucket: bool
        """

        self._is_public_bucket = is_public_bucket

    @property
    def is_vessl_managed(self):
        """Gets the is_vessl_managed of this OrmStorage.  # noqa: E501


        :return: The is_vessl_managed of this OrmStorage.  # noqa: E501
        :rtype: bool
        """
        return self._is_vessl_managed

    @is_vessl_managed.setter
    def is_vessl_managed(self, is_vessl_managed):
        """Sets the is_vessl_managed of this OrmStorage.


        :param is_vessl_managed: The is_vessl_managed of this OrmStorage.  # noqa: E501
        :type is_vessl_managed: bool
        """

        self._is_vessl_managed = is_vessl_managed

    @property
    def organization_credentials_id(self):
        """Gets the organization_credentials_id of this OrmStorage.  # noqa: E501


        :return: The organization_credentials_id of this OrmStorage.  # noqa: E501
        :rtype: int
        """
        return self._organization_credentials_id

    @organization_credentials_id.setter
    def organization_credentials_id(self, organization_credentials_id):
        """Sets the organization_credentials_id of this OrmStorage.


        :param organization_credentials_id: The organization_credentials_id of this OrmStorage.  # noqa: E501
        :type organization_credentials_id: int
        """

        self._organization_credentials_id = organization_credentials_id

    @property
    def provider(self):
        """Gets the provider of this OrmStorage.  # noqa: E501


        :return: The provider of this OrmStorage.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this OrmStorage.


        :param provider: The provider of this OrmStorage.  # noqa: E501
        :type provider: str
        """

        self._provider = provider

    @property
    def region_id(self):
        """Gets the region_id of this OrmStorage.  # noqa: E501


        :return: The region_id of this OrmStorage.  # noqa: E501
        :rtype: int
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this OrmStorage.


        :param region_id: The region_id of this OrmStorage.  # noqa: E501
        :type region_id: int
        """

        self._region_id = region_id

    @property
    def storage_organization(self):
        """Gets the storage_organization of this OrmStorage.  # noqa: E501


        :return: The storage_organization of this OrmStorage.  # noqa: E501
        :rtype: int
        """
        return self._storage_organization

    @storage_organization.setter
    def storage_organization(self, storage_organization):
        """Sets the storage_organization of this OrmStorage.


        :param storage_organization: The storage_organization of this OrmStorage.  # noqa: E501
        :type storage_organization: int
        """

        self._storage_organization = storage_organization

    @property
    def updated_dt(self):
        """Gets the updated_dt of this OrmStorage.  # noqa: E501


        :return: The updated_dt of this OrmStorage.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_dt

    @updated_dt.setter
    def updated_dt(self, updated_dt):
        """Sets the updated_dt of this OrmStorage.


        :param updated_dt: The updated_dt of this OrmStorage.  # noqa: E501
        :type updated_dt: datetime
        """

        self._updated_dt = updated_dt

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmStorage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmStorage):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmSweepEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_by': 'OrmUser',
        'experiments': 'list[OrmExperiment]',
        'histories': 'list[OrmSweepHistory]',
        'kernel_cluster': 'OrmKernelCluster',
        'kernel_cluster_node': 'OrmKernelClusterNode',
        'kernel_image': 'OrmKernelImage',
        'kernel_resource_spec': 'OrmKernelResourceSpec',
        'organization': 'OrmOrganization',
        'project': 'OrmProject'
    }

    attribute_map = {
        'created_by': 'created_by',
        'experiments': 'experiments',
        'histories': 'histories',
        'kernel_cluster': 'kernel_cluster',
        'kernel_cluster_node': 'kernel_cluster_node',
        'kernel_image': 'kernel_image',
        'kernel_resource_spec': 'kernel_resource_spec',
        'organization': 'organization',
        'project': 'project'
    }

    def __init__(self, created_by=None, experiments=None, histories=None, kernel_cluster=None, kernel_cluster_node=None, kernel_image=None, kernel_resource_spec=None, organization=None, project=None, local_vars_configuration=None):  # noqa: E501
        """OrmSweepEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_by = None
        self._experiments = None
        self._histories = None
        self._kernel_cluster = None
        self._kernel_cluster_node = None
        self._kernel_image = None
        self._kernel_resource_spec = None
        self._organization = None
        self._project = None
        self.discriminator = None

        if created_by is not None:
            self.created_by = created_by
        if experiments is not None:
            self.experiments = experiments
        if histories is not None:
            self.histories = histories
        if kernel_cluster is not None:
            self.kernel_cluster = kernel_cluster
        if kernel_cluster_node is not None:
            self.kernel_cluster_node = kernel_cluster_node
        if kernel_image is not None:
            self.kernel_image = kernel_image
        if kernel_resource_spec is not None:
            self.kernel_resource_spec = kernel_resource_spec
        if organization is not None:
            self.organization = organization
        if project is not None:
            self.project = project

    @property
    def created_by(self):
        """Gets the created_by of this OrmSweepEdges.  # noqa: E501


        :return: The created_by of this OrmSweepEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this OrmSweepEdges.


        :param created_by: The created_by of this OrmSweepEdges.  # noqa: E501
        :type created_by: OrmUser
        """

        self._created_by = created_by

    @property
    def experiments(self):
        """Gets the experiments of this OrmSweepEdges.  # noqa: E501


        :return: The experiments of this OrmSweepEdges.  # noqa: E501
        :rtype: list[OrmExperiment]
        """
        return self._experiments

    @experiments.setter
    def experiments(self, experiments):
        """Sets the experiments of this OrmSweepEdges.


        :param experiments: The experiments of this OrmSweepEdges.  # noqa: E501
        :type experiments: list[OrmExperiment]
        """

        self._experiments = experiments

    @property
    def histories(self):
        """Gets the histories of this OrmSweepEdges.  # noqa: E501


        :return: The histories of this OrmSweepEdges.  # noqa: E501
        :rtype: list[OrmSweepHistory]
        """
        return self._histories

    @histories.setter
    def histories(self, histories):
        """Sets the histories of this OrmSweepEdges.


        :param histories: The histories of this OrmSweepEdges.  # noqa: E501
        :type histories: list[OrmSweepHistory]
        """

        self._histories = histories

    @property
    def kernel_cluster(self):
        """Gets the kernel_cluster of this OrmSweepEdges.  # noqa: E501


        :return: The kernel_cluster of this OrmSweepEdges.  # noqa: E501
        :rtype: OrmKernelCluster
        """
        return self._kernel_cluster

    @kernel_cluster.setter
    def kernel_cluster(self, kernel_cluster):
        """Sets the kernel_cluster of this OrmSweepEdges.


        :param kernel_cluster: The kernel_cluster of this OrmSweepEdges.  # noqa: E501
        :type kernel_cluster: OrmKernelCluster
        """

        self._kernel_cluster = kernel_cluster

    @property
    def kernel_cluster_node(self):
        """Gets the kernel_cluster_node of this OrmSweepEdges.  # noqa: E501


        :return: The kernel_cluster_node of this OrmSweepEdges.  # noqa: E501
        :rtype: OrmKernelClusterNode
        """
        return self._kernel_cluster_node

    @kernel_cluster_node.setter
    def kernel_cluster_node(self, kernel_cluster_node):
        """Sets the kernel_cluster_node of this OrmSweepEdges.


        :param kernel_cluster_node: The kernel_cluster_node of this OrmSweepEdges.  # noqa: E501
        :type kernel_cluster_node: OrmKernelClusterNode
        """

        self._kernel_cluster_node = kernel_cluster_node

    @property
    def kernel_image(self):
        """Gets the kernel_image of this OrmSweepEdges.  # noqa: E501


        :return: The kernel_image of this OrmSweepEdges.  # noqa: E501
        :rtype: OrmKernelImage
        """
        return self._kernel_image

    @kernel_image.setter
    def kernel_image(self, kernel_image):
        """Sets the kernel_image of this OrmSweepEdges.


        :param kernel_image: The kernel_image of this OrmSweepEdges.  # noqa: E501
        :type kernel_image: OrmKernelImage
        """

        self._kernel_image = kernel_image

    @property
    def kernel_resource_spec(self):
        """Gets the kernel_resource_spec of this OrmSweepEdges.  # noqa: E501


        :return: The kernel_resource_spec of this OrmSweepEdges.  # noqa: E501
        :rtype: OrmKernelResourceSpec
        """
        return self._kernel_resource_spec

    @kernel_resource_spec.setter
    def kernel_resource_spec(self, kernel_resource_spec):
        """Sets the kernel_resource_spec of this OrmSweepEdges.


        :param kernel_resource_spec: The kernel_resource_spec of this OrmSweepEdges.  # noqa: E501
        :type kernel_resource_spec: OrmKernelResourceSpec
        """

        self._kernel_resource_spec = kernel_resource_spec

    @property
    def organization(self):
        """Gets the organization of this OrmSweepEdges.  # noqa: E501


        :return: The organization of this OrmSweepEdges.  # noqa: E501
        :rtype: OrmOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrmSweepEdges.


        :param organization: The organization of this OrmSweepEdges.  # noqa: E501
        :type organization: OrmOrganization
        """

        self._organization = organization

    @property
    def project(self):
        """Gets the project of this OrmSweepEdges.  # noqa: E501


        :return: The project of this OrmSweepEdges.  # noqa: E501
        :rtype: OrmProject
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this OrmSweepEdges.


        :param project: The project of this OrmSweepEdges.  # noqa: E501
        :type project: OrmProject
        """

        self._project = project

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmSweepEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmSweepEdges):
            return True

        return self.to_dict() != other.to_dict()
